@@ -2,8 +2,7 @@ import sys
 import pathlib
 import time
 import datetime as dt
-sys.path.insert(0, f"{pathlib.Path(__file__).parent.resolve()}/")
-sys.path.insert(1, f"{pathlib.Path(__file__).parent.resolve()}\\")
+sys.path.insert(0, f"{pathlib.Path(__file__).parent.resolve()}")
 
 from FastTelethon import upload_file, download_file
 
